CameraPosition class Navigation View Map View Android Auto Carplay

Represents the camera position in a Google Maps view.

Constructors

CameraPosition({double bearing = 0, LatLng target = const LatLng(latitude: 0, longitude: 0), double tilt = 0, double zoom = 3.0})
Creates a CameraPosition object with map centered to the target with the given bearing, tilt and zoom level.
const

Properties

bearing → double
Bearing of the camera, in degrees clockwise from true north.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → LatLng
The location that the camera is pointing at.
final
tilt → double
The angle, in degrees, of the camera angle from the nadir (directly facing the Earth).
final
zoom → double
Zoom level near the center of the screen.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited