clear method
Remove all markers, polylines, polygons, overlays, etc from the map view.
Implementation
Future<void> clear() {
return GoogleMapsNavigationPlatform.instance.viewAPI.clear(viewId: _viewId);
}
Remove all markers, polylines, polygons, overlays, etc from the map view.
Future<void> clear() {
return GoogleMapsNavigationPlatform.instance.viewAPI.clear(viewId: _viewId);
}