GoogleNavigationViewController class Navigation View

Navigation View Controller class to handle navigation view events.

Inheritance

Constructors

GoogleNavigationViewController(int viewId)
Basic constructor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → NavigationViewUISettings
Settings for the user interface of the map.
finalinherited

Methods

activateIndoorLevel(IndoorLevel indoorLevel) → Future<void>
Activates an indoor level within the currently focused indoor building.
inherited
addCircles(List<CircleOptions> options) → Future<List<Circle?>>
Add circles to the map view.
inherited
addMarkers(List<MarkerOptions> markerOptions) → Future<List<Marker?>>
Add markers to the map view.
inherited
addPolygons(List<PolygonOptions> polygonOptions) → Future<List<Polygon?>>
Add polygons to the map view.
inherited
addPolylines(List<PolylineOptions> polylineOptions) → Future<List<Polyline?>>
Add polylines to the map view.
inherited
animateCamera(CameraUpdate cameraUpdate, {Duration? duration, AnimationFinishedCallback? onFinished}) → Future<void>
Animates the movement of the camera from the current position to the position defined in the cameraUpdate.
inherited
clear() → Future<void>
Remove all markers, polylines, polygons, overlays, etc from the map view.
inherited
clearCircles() → Future<void>
Remove all circles from the map view.
inherited
clearMarkers() → Future<void>
Remove all markers from the map view.
inherited
clearPolygons() → Future<void>
Remove all polygons from the map view.
inherited
clearPolylines() → Future<void>
Remove all polylines from the map view.
inherited
followMyLocation(CameraPerspective perspective, {double? zoomLevel}) → Future<void>
Ask the camera to follow the user's location.
inherited
getCameraPosition() → Future<CameraPosition>
Gets the current position of the camera.
inherited
getCircles() → Future<List<Circle?>>
Gets all circles from the map view.
inherited
getFocusedIndoorBuilding() → Future<IndoorBuilding?>
Gets the currently focused indoor building, if available.
inherited
getForceNightMode() → Future<NavigationForceNightMode>
Gets the current force night mode setting from the navigation view.
getMapColorScheme() → Future<MapColorScheme>
Gets the current map color scheme from the map view.
inherited
getMapType() → Future<MapType>
This method returns the current map type of the Google Maps view instance.
inherited
getMarkers() → Future<List<Marker?>>
Retrieves all markers that have been added to the map view.
inherited
getMaxZoomPreference() → Future<double>
Returns the maximum zoom level preference from the map view. If maximum zoom preference is not set previously, returns maximum possible zoom level for the current map type.
inherited
getMinZoomPreference() → Future<double>
Returns the minimum zoom level preference from the map view. If minimum zoom preference is not set previously, returns minimum possible zoom level for the current map type.
inherited
getMyLocation() → Future<LatLng?>
Gets user's current location.
inherited
getNavigationHeaderStylingOptions() → Future<NavigationHeaderStylingOptions>
Returns the native navigation header styling options.
getPadding() → Future<EdgeInsets>
Gets map-view padding in logical pixels.
inherited
getPolygons() → Future<List<Polygon?>>
Retrieves all polygons that have been added to the map view.
inherited
getPolylines() → Future<List<Polyline?>>
Retrieves all polylines that have been added to the map view.
inherited
getViewId() → int
Getter for view ID.
inherited
getVisibleRegion() → Future<LatLngBounds>
Gets the current visible map region or camera bounds.
inherited
isBuildingsEnabled() → Future<bool>
Checks if the 3D buildings layer is enabled.
inherited
isIncidentReportingAvailable() → Future<bool>
Checks if incident reporting is currently available.
isIndoorEnabled() → Future<bool>
Checks if the indoor maps layer is enabled.
inherited
isMyLocationEnabled() → Future<bool>
Gets whether the my location is enabled or disabled.
inherited
isNavigationFooterEnabled() → Future<bool>
Checks if the navigation footer is enabled.
isNavigationHeaderEnabled() → Future<bool>
Checks if the navigation header is enabled.
isNavigationTripProgressBarEnabled() → Future<bool>
Checks if the navigation trip progress bar is enabled.
isNavigationUIEnabled() → Future<bool>
Check if the navigation user interface is shown.
isRecenterButtonEnabled() → Future<bool>
Checks if the recenter button is enabled.
inherited
isReportIncidentButtonEnabled() → Future<bool>
Checks if the report incident button is shown.
isSpeedLimitIconEnabled() → Future<bool>
Can the speed limit indication be displayed.
isSpeedometerEnabled() → Future<bool>
Can the speedometer be displayed.
isTrafficIncidentCardsEnabled() → Future<bool>
Are the incident cards displayed.
isTrafficPromptsEnabled() → Future<bool>
Are the traffic prompts shown.
moveCamera(CameraUpdate cameraUpdate) → Future<void>
Moves the camera from the current position to the position defined in the cameraUpdate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCircles(List<Circle> circles) → Future<void>
Remove circles from the map view.
inherited
removeMarkers(List<Marker> markers) → Future<void>
Remove markers from the map view.
inherited
removePolygons(List<Polygon> polygons) → Future<void>
Remove polygons from the map view.
inherited
removePolylines(List<Polyline> polylines) → Future<void>
Remove polylines from the map view.
inherited
resetMinMaxZoomPreference() → Future<void>
Removes any previously specified upper and lower zoom bounds.
inherited
setBuildingsEnabled(bool enabled) → Future<void>
Enable or disable the 3D buildings layer.
inherited
setForceNightMode(NavigationForceNightMode forceNightMode) → Future<void>
Sets the force night mode for the navigation UI and map tiles.
setIndoorEnabled(bool enabled) → Future<void>
Enable or disable the indoor maps layer.
inherited
setMapColorScheme(MapColorScheme mapColorScheme) → Future<void>
Sets the map color scheme for the map view.
inherited
setMapStyle(String? styleJson) → Future<void>
Sets the styling of the base map using a string containing JSON. Null value will reset the base map to default style. If styleJson is invalid throws MapStyleException.
inherited
setMapType({required MapType mapType}) → Future<void>
Changes the type of the map being displayed on the Google Maps view.
inherited
setMaxZoomPreference(double maxZoomPreference) → Future<void>
Sets a preferred upper bound for the camera zoom.
inherited
setMinZoomPreference(double minZoomPreference) → Future<void>
Sets a preferred lower bound for the camera zoom.
inherited
setMyLocationEnabled(bool enabled) → Future<void>
Change status of my location enabled.
inherited
setNavigationFooterEnabled(bool enabled) → Future<void>
Enable or disable the navigation footer.
setNavigationHeaderEnabled(bool enabled) → Future<void>
Enable or disable the navigation header.
setNavigationHeaderStylingOptions(NavigationHeaderStylingOptions stylingOptions) → Future<void>
Sets the native navigation header styling options.
setNavigationTripProgressBarEnabled(bool enabled) → Future<void>
Enable or disable the navigation trip progress bar.
setNavigationUIEnabled(bool enabled) → Future<void>
Show or hide the navigation user interface shown on top of the map.
setPadding(EdgeInsets padding) → Future<void>
Sets map-view padding in logical pixels.
inherited
setRecenterButtonEnabled(bool enabled) → Future<void>
Enable or disable the recenter button.
inherited
setReportIncidentButtonEnabled(bool enabled) → Future<void>
Enable or disable showing of the report incident button.
setSpeedLimitIconEnabled(bool enabled) → Future<void>
Allow showing the speed limit indicator.
setSpeedometerEnabled(bool enabled) → Future<void>
Allow showing the speedometer.
setTrafficIncidentCardsEnabled(bool enabled) → Future<void>
Enable or disable showing of the incident cards.
setTrafficPromptsEnabled(bool enabled) → Future<void>
Enable or disable showing of the traffic prompts.
showReportIncidentsPanel() → Future<void>
Presents a panel allowing users to report an incident.
showRouteOverview() → Future<void>
Move the map camera to show the route overview.
toString() → String
A string representation of this object.
inherited
updateCircles(List<Circle> circles) → Future<List<Circle?>>
Update circles to the map view.
inherited
updateMarkers(List<Marker> markers) → Future<List<Marker?>>
Update markers to the map view.
inherited
updatePolygons(List<Polygon> polygons) → Future<List<Polygon?>>
Update polygons to the map view.
inherited
updatePolylines(List<Polyline> polylines) → Future<List<Polyline?>>
Update polylines to the map view.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited