GpsAvailabilityChangeEvent class Navigation

GpsAvailabilityChange event message (Android only).

Constructors

GpsAvailabilityChangeEvent({required bool isGpsLost, required bool isGpsValidForNavigation})
Initialize GPS availability change event message.

Properties

hashCode int
The hash code for this object.
no setterinherited
isGpsLost bool
Indicates a GPS signal or other sensors good enough for a reasonably certain location have been lost.
final
isGpsValidForNavigation bool
Indicates a GPS signal or other sensors are in general good enough for use in navigation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited