GpsAvailabilityUpdatedEvent class Navigation

GpsAvailabilityUpdated event message (Android only).

Annotations
  • @Deprecated('Use getNavigationOnGpsAvailabilityChangeEventStream and GpsAvailabilityChangeEvent instead')

Constructors

GpsAvailabilityUpdatedEvent({required bool available})
Initialize GPS availability updated event message.

Properties

available bool
GPS availability.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited