IndoorLevel class Navigation View Map View

Represents one indoor level in a focused indoor building.

Annotations

Constructors

IndoorLevel({required int levelIndex, required String? name, required String? shortName})
Creates an IndoorLevel object.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
levelIndex → int
Stable index of this level within the containing focused building levels list.
final
name → String?
Full display name of the level.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName → String?
Short display name of the level.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override