LatLngBounds class Navigation View Map View Android Auto Carplay

LatLngBounds bounds object.

Annotations

Constructors

LatLngBounds({required LatLng southwest, required LatLng northeast})
Initialize LatLngBounds with the given southwest and northeast points.

Properties

center → LatLng
Returns the center of this LatLngBounds.
no setter
hashCode → int
The hash code for this object.
no setteroverride
latitudeSpan → double
Returns the latitude span of this LatLngBounds.
no setter
longitudeSpan → double
Returns the longitude span of this LatLngBounds.
no setter
northeast → LatLng
Northeast corner of the bound.
final
northwest → LatLng
Northwest corner of the bound
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
southeast → LatLng
Southeast corner of the bound
no setter
southwest → LatLng
Southwest corner of the bound.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(LatLng latLngOffset) → LatLngBounds
Returns a new LatLngBounds instance offset by the given LatLng.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

createBoundsFromPoints(List<LatLng> points) → LatLngBounds
Returns a new LatLngBounds instance that is the smallest bounding box that contains list of given LatLng points.