Marker class Navigation View Map View Android Auto Carplay

Marker that has beed added to the map.

Annotations

Constructors

Marker({required String markerId, required MarkerOptions options})
Construct Marker
const

Properties

hashCode int
The hash code for this object.
no setteroverride
markerId String
Identifies the marker.
final
options MarkerOptions
Options for the marker.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({required MarkerOptions options}) Marker
Create copy of Marker with the specified options.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override