MarkerDragEvent class Navigation View Map View

Marker drag event sent from platform side.

Annotations

Constructors

MarkerDragEvent({required String markerId, required MarkerDragEventType eventType, required LatLng position})
Initialize MarkerDragEvent object.
const

Properties

eventType → MarkerDragEventType
Type of the event.
final
hashCode → int
The hash code for this object.
no setterinherited
markerId → String
Id of the marker that has been tapped.
final
position → LatLng
Position of the marker that has been dragged.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited