MarkerEvent class Navigation View Map View

Marker event sent from platform side.

Annotations

Constructors

MarkerEvent({required String markerId, required MarkerEventType eventType})
Initialize MarkerEvent object.
const

Properties

eventType MarkerEventType
Type of the event.
final
hashCode int
The hash code for this object.
no setterinherited
markerId String
Id of the marker that has been tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited