NavInfo class Navigation

Contains information about the state of navigation, the current nav step if available, and remaining steps if available.

Constructors

Construct NavInfo.

Properties

currentStep StepInfo?
Information about the upcoming maneuver step.
getter/setter pair
distanceToCurrentStepMeters int?
Estimated remaining distance in meters along the route to the current step.
final
distanceToFinalDestinationMeters int?
The estimated remaining distance in meters to the final destination which is the last destination in a multi-destination trip.
final
distanceToNextDestinationMeters int?
The estimated remaining distance in meters to the next destination.
final
hashCode int
The hash code for this object.
no setterinherited
The current state of navigation.
getter/setter pair
remainingSteps List<StepInfo>
The remaining steps after the current step.
getter/setter pair
routeChanged bool
Whether the route has changed since the last sent message.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeToCurrentStepSeconds int?
The estimated remaining time in seconds along the route to the current step.
final
timeToFinalDestinationSeconds int?
The estimated remaining time in seconds to the final destination which is the last destination in a multi-destination trip.
final
timeToNextDestinationSeconds int?
The estimated remaining time in seconds to the next destination.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited