timeToCurrentStepSeconds property
The estimated remaining time in seconds along the route to the current step.
Implementation
final int? timeToCurrentStepSeconds;
The estimated remaining time in seconds along the route to the current step.
final int? timeToCurrentStepSeconds;