NavInfoEvent class
NavInfo event message
Constructors
- Initialize with NavInfo object.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Navigation information.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited