NavigationForceNightMode enum Navigation View

Navigation night mode.

Controls the navigation UI lighting mode for Navigation views. This affects the color scheme and visibility of navigation UI elements.

Android ref: https://developers.google.com/maps/documentation/navigation/android-sdk/reference/com/google/android/libraries/navigation/ForceNightMode iOS ref: https://developers.google.com/maps/documentation/navigation/ios-sdk/reference/objc/Enums/GMSNavigationLightingMode

Inheritance
Available extensions

Values

auto → const NavigationForceNightMode

Let the SDK automatically determine day or night mode based on time and location.

forceDay → const NavigationForceNightMode

Force day mode regardless of time or location.

forceNight → const NavigationForceNightMode

Force night mode regardless of time or location.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NavigationForceNightMode>
A constant List of the values in this enum, in order of their declaration.