NavigationTimeAndDistance class Navigation

Time and distance to next waypoint.

Constructors

Initialize with time, distance, and delay severity.

Properties

delaySeverity → TrafficDelaySeverity
Traffic delay severity.
final
distance → double
Distance to destination in meters.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → double
Time to destination in seconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited