PointOfInterest class Navigation View Map View

Represents a point of interest (POI) on the map. POIs include parks, schools, government buildings, and businesses.

Annotations

Constructors

PointOfInterest({required String placeID, required String name, required LatLng latLng})
Creates a PointOfInterest object.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
latLng LatLng
The geographical coordinates of the POI.
final
name String
The name of the POI (e.g., "Central Park", "City Hall").
final
placeID String
The Place ID of this POI, as defined in the Places SDK. This identifier can be used to retrieve additional information about the place using the Places API.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override