PolygonNotFoundException class Map View
GoogleNavigationViewController.updatePolygons or GoogleNavigationViewController.removePolygons failed to find the polygon given to the method.
- Inheritance
-
- Object
- PlatformException
- GoogleMapsNavigationPlatformException
- PolygonNotFoundException
Constructors
- PolygonNotFoundException({required PlatformException exception})
- Creates a PolygonNotFoundException from an original PlatformException.
Properties
- code → String
-
An error code.
finalinherited
- details → dynamic
-
Error details, possibly null.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
A human-readable error message, possibly null.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stacktrace → String?
-
Native stacktrace for the error, possibly null.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- platformCode → const String