RouteSegment class Navigation View

Navigation route segment

Constructors

RouteSegment({RouteSegmentTrafficData? trafficData, required LatLng destinationLatLng, required List<LatLng?>? latLngs, required NavigationWaypoint? destinationWaypoint})
Initialize with traffic data (Android only), destination coordinate, traveled route and destination waypoint.

Properties

destinationLatLng → LatLng
Destination coordinate.
final
destinationWaypoint → NavigationWaypoint?
Destination waypoint.
final
hashCode → int
The hash code for this object.
no setterinherited
latLngs → List<LatLng?>?
Traveled route.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trafficData → RouteSegmentTrafficData?
Traffic data (Android only).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited