RouteSegmentTrafficData class Navigation View

Route segment traffic data.

Constructors

RouteSegmentTrafficData({required RouteSegmentTrafficDataStatus status, required List<RouteSegmentTrafficDataRoadStretchRenderingData?> roadStretchRenderingDataList})
Initialize with status, and rendering data list.

Properties

hashCode → int
The hash code for this object.
no setterinherited
roadStretchRenderingDataList → List<RouteSegmentTrafficDataRoadStretchRenderingData?>
Rendering data list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → RouteSegmentTrafficDataStatus
Status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited