RouteTokenMalformedException class

GoogleMapsNavigator.setDestinations method call has failed, because the RouteTokenOptions.routeToken is malformed. (Android only)

Implemented types

Constructors

RouteTokenMalformedException()
Default constructor for RouteTokenMalformedException.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited