RoutingOptions class Navigation

Routing options.

Constructors

RoutingOptions({NavigationAlternateRoutesStrategy? alternateRoutesStrategy, NavigationRoutingStrategy? routingStrategy, List<int?>? targetDistanceMeters, NavigationTravelMode? travelMode, bool? avoidTolls, bool? avoidFerries, bool? avoidHighways, int? locationTimeoutMs})
Routing options initializer with options.

Properties

alternateRoutesStrategy NavigationAlternateRoutesStrategy?
Alternate routes strategy.
final
avoidFerries bool?
Ferries should be avoided.
final
avoidHighways bool?
Highways should be avoided.
final
avoidTolls bool?
Tolls should be avoided.
final
hashCode int
The hash code for this object.
no setterinherited
locationTimeoutMs int?
Maximum time to wait for a location fix before failure. (Only Android)
final
routingStrategy NavigationRoutingStrategy?
Routing strategy.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetDistanceMeters List<int?>?
Target distance meters.
final
travelMode NavigationTravelMode?
Travel mode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited