SessionNotInitializedException class Navigation

GoogleMapsNavigator navigation method call has failed, because the navigation session hasn't yet been successfully initialized.

Implemented types

Constructors

SessionNotInitializedException()
Default constructor for SessionNotInitializedException.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited