StepInfo class Navigation

Information about a single step along a navigation route.

Constructors

StepInfo({required int? distanceFromPrevStepMeters, required int? timeFromPrevStepSeconds, required DrivingSide drivingSide, required String? exitNumber, required String? fullInstructions, required String? fullRoadName, required String? simpleRoadName, required int? roundaboutTurnNumber, required int? stepNumber, required List<Lane>? lanes, required Maneuver maneuver, required ImageDescriptor? maneuverImage, required ImageDescriptor? lanesImage})
Construct StepInfo.

Properties

distanceFromPrevStepMeters int?
Distance in meters from the previous step to this step if available, otherwise null.
final
drivingSide DrivingSide
Whether this step is on a drive-on-right or drive-on-left route.
final
exitNumber String?
The exit number if it exists.
final
fullInstructions String?
The full text of the instruction for this step if available, otherwise null.
final
fullRoadName String?
The full road name for this step if available, otherwise null.
final
hashCode int
The hash code for this object.
no setterinherited
lanes List<Lane>?
The list of available lanes at the end of this route step if available, otherwise null.
final
lanesImage ImageDescriptor?
Image descriptor for the generated lane guidance image for the current step if available, otherwise null. /// This image is generated only if step image generation option includes lane images.
final
maneuver Maneuver
The maneuver for this step.
final
maneuverImage ImageDescriptor?
Image descriptor for the generated maneuver image for the current step if available, otherwise null. /// This image is generated only if step image generation option includes maneuver images.
final
roundaboutTurnNumber int?
The counted number of the exit to take relative to the location where the roundabout was entered if available, otherwise null.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simpleRoadName String?
The simplified version of the road name if available, otherwise null.
final
stepNumber int?
The index of the step in the list of all steps in the route if available, otherwise null.
final
timeFromPrevStepSeconds int?
Time in seconds from the previous step to this step if available, otherwise null.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited