stepNumber property
The index of the step in the list of all steps in the route if available, otherwise null.
Implementation
final int? stepNumber;
The index of the step in the list of all steps in the route if available, otherwise null.
final int? stepNumber;