TaskRemovedBehavior enum Navigation

Determines how application should behave when a application task is removed.

Android only.

Inheritance
Available extensions

Values

continueService → const TaskRemovedBehavior

The default state, indicating that navigation guidance, location updates, and notification should persist after user removes the application task.

quitService → const TaskRemovedBehavior

Indicates that navigation guidance, location updates, and notification should shut down immediately when the user removes the application task.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TaskRemovedBehavior>
A constant List of the values in this enum, in order of their declaration.