TermsAndConditionsUIParams class

UI customization parameters for the Terms and Conditions dialog.

Allows customization of the dialog's appearance by specifying custom colors for various UI elements. All color parameters are optional - if not provided, platform defaults will be used.

Example usage:

final customization = TermsAndConditionsUIParams(
  backgroundColor: Colors.white,
  titleColor: Colors.blue,
  mainTextColor: Colors.black87,
  acceptButtonTextColor: Colors.green,
  cancelButtonTextColor: Colors.red,
);

await GoogleMapsNavigator.showTermsAndConditionsDialog(
  'Terms of Service',
  'My Company',
  uiParams: customization,
);

Constructors

TermsAndConditionsUIParams({Color? backgroundColor, Color? titleColor, Color? mainTextColor, Color? acceptButtonTextColor, Color? cancelButtonTextColor})
Creates a new TermsAndConditionsUIParams with the specified colors.
const

Properties

acceptButtonTextColor → Color?
Text color for the accept button.
final
backgroundColor → Color?
Background color of the dialog box.
final
cancelButtonTextColor → Color?
Text color for the cancel button.
final
hashCode → int
The hash code for this object.
no setterinherited
mainTextColor → Color?
Text color for the main terms and conditions text.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleColor → Color?
Text color for the dialog title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited