ViewNotFoundException class Navigation View Map View

Exception thrown when a platform view is not found.

This exception is typically thrown when an asynchronous operation is attempted on a view that has already been disposed. For example, some controller calls could throw this error if the view is no longer available when the method is handled on the native layer.

Inheritance

Constructors

ViewNotFoundException({required PlatformException exception, required StackTrace stacktrace})
Creates a ViewNotFoundException from an original PlatformException.

Properties

code String
An error code.
finalinherited
details → dynamic
Error details, possibly null.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String?
A human-readable error message, possibly null.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stacktrace String?
Native stacktrace for the error, possibly null.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

platformCode → const String