ContinueToNextDestinationResponse class
Response returned by GoogleMapsNavigator.continueToNextDestination.
Constructors
- ContinueToNextDestinationResponse({NavigationWaypoint? waypoint, NavigationRouteStatus? routeStatus})
- Initialize with waypoint and optional route status.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- routeStatus → NavigationRouteStatus?
-
The route status indicating the result of routing to the next destination.
Only available on iOS. On Android this will be null.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- waypoint → NavigationWaypoint?
-
The waypoint guidance is now heading to, or null if there are no more
waypoints left.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited