Destinations class
Destinations main type.
Asserts if both routeTokenOptions and routingOptions are provided.
Constructors
-
Destinations({required List<
NavigationWaypoint> waypoints, required NavigationDisplayOptions displayOptions, RoutingOptions? routingOptions, RouteTokenOptions? routeTokenOptions}) - Destinations initializer with waypoints and options.
Properties
- displayOptions → NavigationDisplayOptions
-
Navigation display options.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- routeTokenOptions → RouteTokenOptions?
-
Navigation route token options.
final
- routingOptions → RoutingOptions?
-
Navigation routing options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
waypoints
→ List<
NavigationWaypoint> -
List of navigation waypoints.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited