Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
activateIndoorLevel (IndoorLevel indoorLevel )
→ Future <void >
Activates an indoor level on the currently focused indoor building.
addCircles (List <CircleOptions > options )
→ Future <List <Circle ? > >
Add circles to the map view.
addMarkers (List <MarkerOptions > markerOptions )
→ Future <List <Marker ? > >
Add markers to the map view.
addPolygons (List <PolygonOptions > polygonOptions )
→ Future <List <Polygon ? > >
Add polygons to the map view.
addPolylines (List <PolylineOptions > polylineOptions )
→ Future <List <Polyline ? > >
Add polylines to the map view.
animateCamera (CameraUpdate cameraUpdate , {Duration ? duration , AnimationFinishedCallback ? onFinished })
→ Future <void >
Animates the movement of the camera from the current position
to the position defined in the cameraUpdate.
clear ()
→ Future <void >
Remove all markers, polylines, polygons, overlays, etc from the map view.
clearCircles ()
→ Future <void >
Remove all circles from the map view.
clearMarkers ()
→ Future <void >
Remove all markers from the map view.
clearPolygons ()
→ Future <void >
Remove all polygons from the map view.
clearPolylines ()
→ Future <void >
Remove all polylines from the map view.
followMyLocation (CameraPerspective perspective , {double ? zoomLevel })
→ Future <void >
Ask the camera to follow the user's location.
getCameraPosition ()
→ Future <CameraPosition >
Gets the current position of the camera.
getCircles ()
→ Future <List <Circle ? > >
Gets all circles from the map view.
getFocusedIndoorBuilding ()
→ Future <IndoorBuilding ? >
Gets metadata for the currently focused indoor building, if available.
getForceNightMode ()
→ Future <NavigationForceNightMode >
Gets the current force night mode setting for the Android Auto or CarPlay navigation view.
getMapColorScheme ()
→ Future <MapColorScheme >
Gets the current map color scheme for the Android Auto or CarPlay view.
getMapType ()
→ Future <MapType >
This method returns the current map type of the Google Maps view instance.
getMarkers ()
→ Future <List <Marker ? > >
Retrieves all markers that have been added to the map view.
getMaxZoomPreference ()
→ Future <double >
Returns the maximum zoom level preference from the map view.
If maximum zoom preference is not set previously, returns maximum possible
zoom level for the current map type.
getMinZoomPreference ()
→ Future <double >
Returns the minimum zoom level preference from the map view.
If minimum zoom preference is not set previously, returns minimum possible
zoom level for the current map type.
getMyLocation ()
→ Future <LatLng ? >
Gets user's current location.
getPadding ()
→ Future <EdgeInsets >
getPolygons ()
→ Future <List <Polygon ? > >
Retrieves all polygons that have been added to the map view.
getPolylines ()
→ Future <List <Polyline ? > >
Retrieves all polylines that have been added to the map view.
getVisibleRegion ()
→ Future <LatLngBounds >
Gets the current visible map region or camera bounds.
isAutoScreenAvailable ()
→ Future <bool >
Returns whether the Android Auto or CarPlay map view is currently available.
isIndoorEnabled ()
→ Future <bool >
Returns whether indoor maps are enabled on the Android Auto or CarPlay map view.
isMyLocationEnabled ()
→ Future <bool >
Gets whether the my location is enabled or disabled.
isNavigationTripProgressBarEnabled ()
→ Future <bool >
Returns whether the navigation trip progress bar is enabled on the
Android Auto or CarPlay map view.
isNavigationUIEnabled ()
→ Future <bool >
Returns whether the navigation UI is enabled on the Android Auto or CarPlay map view.
isSpeedLimitIconEnabled ()
→ Future <bool >
Returns whether the speed limit icon is enabled on the
Android Auto or CarPlay map view.
isSpeedometerEnabled ()
→ Future <bool >
Returns whether the speedometer is enabled on the
Android Auto or CarPlay map view.
isTrafficIncidentCardsEnabled ()
→ Future <bool >
Returns whether traffic incident cards are currently enabled on the
Android Auto or CarPlay map view.
isTrafficPromptsEnabled ()
→ Future <bool >
Returns whether traffic prompts are currently enabled on the
Android Auto or CarPlay map view.
listenForAutoScreenAvailibilityChangedEvent (void func (AutoScreenAvailabilityChangedEvent event ) )
→ void
Listens for changes in Android Auto or CarPlay screen availability.
listenForCustomNavigationAutoEvents (void func (CustomNavigationAutoEvent event ) )
→ void
Listens for custom navigation events sent from the native Android Auto or CarPlay code.
listenForIndoorActiveLevelChangedEvent (void func (IndoorActiveLevelChangedEvent event ) )
→ void
Listens for active indoor level changes on Android Auto or CarPlay.
listenForIndoorFocusedBuildingChangedEvent (void func (IndoorFocusedBuildingChangedEvent event ) )
→ void
Listens for focused indoor building changes on Android Auto or CarPlay.
listenForNavigationUIEnabledChangedEvent (void func (NavigationUIEnabledChangedEvent event ) )
→ void
Listens for navigation UI enabled state changes on Android Auto or CarPlay.
listenForPromptVisibilityChangedEvent (void func (PromptVisibilityChangedEvent event ) )
→ void
Listens for prompt visibility changes on Android Auto or CarPlay.
moveCamera (CameraUpdate cameraUpdate )
→ Future <void >
Moves the camera from the current position to the position
defined in the cameraUpdate.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCircles (List <Circle > circles )
→ Future <void >
Remove circles from the map view.
removeMarkers (List <Marker > markers )
→ Future <void >
Remove markers from the map view.
removePolygons (List <Polygon > polygons )
→ Future <void >
Remove polygons from the map view.
removePolylines (List <Polyline > polylines )
→ Future <void >
Remove polylines from the map view.
resetMinMaxZoomPreference ()
→ Future <void >
Removes any previously specified upper and lower zoom bounds.
sendCustomNavigationAutoEvent (String event , Object data )
→ Future <void >
Sends a custom event from Flutter to the native Android Auto or CarPlay implementation.
setForceNightMode (NavigationForceNightMode forceNightMode )
→ Future <void >
Sets the force night mode for the Android Auto or CarPlay navigation view.
setIndoorEnabled (bool enabled )
→ Future <void >
Enables or disables indoor maps on the Android Auto or CarPlay map view.
setMapColorScheme (MapColorScheme mapColorScheme )
→ Future <void >
Sets the map color scheme for the Android Auto or CarPlay view.
setMapStyle (String ? styleJson )
→ Future <void >
Sets the styling of the base map using a string containing JSON.
Null value will reset the base map to default style.
If styleJson is invalid throws MapStyleException .
setMapType ({required MapType mapType })
→ Future <void >
Changes the type of the map being displayed on the Google Maps view.
setMaxZoomPreference (double maxZoomPreference )
→ Future <void >
Sets a preferred upper bound for the camera zoom.
setMinZoomPreference (double minZoomPreference )
→ Future <void >
Sets a preferred lower bound for the camera zoom.
setMyLocationEnabled (bool enabled )
→ Future <void >
Change status of my location enabled.
setNavigationTripProgressBarEnabled (bool enabled )
→ Future <void >
Sets whether the navigation trip progress bar is enabled on the
Android Auto or CarPlay view.
setNavigationUIEnabled (bool enabled )
→ Future <void >
Sets whether the navigation UI is enabled on the Android Auto or CarPlay map view.
setPadding (EdgeInsets padding )
→ Future <void >
Set padding for the map view.
setSpeedLimitIconEnabled (bool enabled )
→ Future <void >
Sets whether the speed limit icon is enabled on the Android Auto or CarPlay view.
setSpeedometerEnabled (bool enabled )
→ Future <void >
Sets whether the speedometer is enabled on the Android Auto or CarPlay view.
setTrafficIncidentCardsEnabled (bool enabled )
→ Future <void >
Sets whether traffic incident cards are enabled on the Android Auto or CarPlay view.
setTrafficPromptsEnabled (bool enabled )
→ Future <void >
Enable or disable traffic prompts on the Android Auto or CarPlay map view.
showRouteOverview ()
→ Future <void >
Shows the route overview on the Android Auto or CarPlay map view.
toString ()
→ String
A string representation of this object.
inherited
updateCircles (List <Circle > circles )
→ Future <List <Circle ? > >
Update circles to the map view.
updateMarkers (List <Marker > markers )
→ Future <List <Marker ? > >
Update markers to the map view.
updatePolygons (List <Polygon > polygons )
→ Future <List <Polygon ? > >
Update polygons to the map view.
updatePolylines (List <Polyline > polylines )
→ Future <List <Polyline ? > >
Update polylines to the map view.
google_navigation_flutter 0.10.0