LatLng class Navigation Navigation View Map View Android Auto Carplay

LatLng coordinate object.

Annotations

Constructors

LatLng({required double latitude, required double longitude})
Initializes a LatLng with the provided latitude and longitude values.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
latitude double
The latitude of this point in degrees, where negative values indicate south of the equator.
final
longitude double
The longitude of this point in degrees, where negative values indicate west of the prime meridian.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offset(LatLng offset) LatLng
Returns a new LatLng instance offset by the given LatLng. Asserts that the operation does not cross the poles.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override
operator unary-() LatLng
Returns a new LatLng instance with the latitude and longitude negated.