MapViewInitializationOptions class Map View
Encapsulates the initial configuration required to initialize the navigation map view.
This class is used to specify various map and navigation settings at the time of map initialization. Example:
final settings = NavigationViewInitializationOptions(
mapOptions: MapOptions(
cameraPosition: CameraPosition(
target: LatLng(37.4219999,-122.0840575),
zoom: 14.4746,
),
mapType: MapType.normal,
compassEnabled: true,
// ... other parameters
)
);
- Annotations
Constructors
-
MapViewInitializationOptions({required TextDirection layoutDirection, required MapOptions mapOptions, Set<
Factory< gestureRecognizers = const <Factory<OneSequenceGestureRecognizer>>{}})OneSequenceGestureRecognizer> > -
Creates a new instance of MapViewInitializationOptions with the given initial
parameters to configure the navigation view.
const
Properties
-
gestureRecognizers
→ Set<
Factory< OneSequenceGestureRecognizer> > -
Specifies the gestures to be forwarded to the
PlatformViewfor processing.final - hashCode → int
-
The hash code for this object.
no setterinherited
- layoutDirection → TextDirection
-
A direction in which text flows on the widget.
final
- mapOptions → MapOptions
-
The initial map options for the map view.
final
-
The initial navigation options for the navigation view.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited