PromptVisibilityChangedEvent class
Represents prompt visibility changed event in a view.
Constructors
- PromptVisibilityChangedEvent(bool promptVisible)
-
Creates a PromptVisibilityChangedEvent object.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- promptVisible → bool
-
Value representing whether prompts are visible or not.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited