RemainingTimeOrDistanceChangedEvent class
Remaining time or distance change event message.
Constructors
- RemainingTimeOrDistanceChangedEvent({required double remainingDistance, required double remainingTime, required TrafficDelaySeverity delaySeverity})
- Initialize with remaining distance in meters, remaining time in seconds and delay severity.
Properties
- delaySeverity → TrafficDelaySeverity
-
Traffic delay severity.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- remainingDistance → double
-
Remaining distance in meters.
final
- remainingTime → double
-
Remaining time in seconds.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited