SpeedingUpdatedEvent class
SpeedingUpdated event message.
Constructors
- SpeedingUpdatedEvent({required double percentageAboveLimit, required SpeedAlertSeverity severity})
- Initialize speeding updated event message.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- percentageAboveLimit → double
-
Percentage above speed limit.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → SpeedAlertSeverity
-
Severity of the speeding.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited